package com.sundot.airport.personnel.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.sundot.airport.personnel.domain.PersonnelMonthlyAssessmentIndicatorRewardPunishmentDetail;

/**
 * 月度考核指标奖罚明细Service接口
 *
 * @author ruoyi
 * @date 2026-05-07
 */
public interface IPersonnelMonthlyAssessmentIndicatorRewardPunishmentDetailService extends IService<PersonnelMonthlyAssessmentIndicatorRewardPunishmentDetail> {
    /**
     * 查询月度考核指标奖罚明细
     *
     * @param id 月度考核指标奖罚明细主键
     * @return 月度考核指标奖罚明细
     */
    public PersonnelMonthlyAssessmentIndicatorRewardPunishmentDetail selectPersonnelMonthlyAssessmentIndicatorRewardPunishmentDetailById(Long id);

    /**
     * 查询月度考核指标奖罚明细列表
     *
     * @param personnelMonthlyAssessmentIndicatorRewardPunishmentDetail 月度考核指标奖罚明细
     * @return 月度考核指标奖罚明细集合
     */
    public List<PersonnelMonthlyAssessmentIndicatorRewardPunishmentDetail> selectPersonnelMonthlyAssessmentIndicatorRewardPunishmentDetailList(PersonnelMonthlyAssessmentIndicatorRewardPunishmentDetail personnelMonthlyAssessmentIndicatorRewardPunishmentDetail);

    /**
     * 新增月度考核指标奖罚明细
     *
     * @param personnelMonthlyAssessmentIndicatorRewardPunishmentDetail 月度考核指标奖罚明细
     * @return 结果
     */
    public int insertPersonnelMonthlyAssessmentIndicatorRewardPunishmentDetail(PersonnelMonthlyAssessmentIndicatorRewardPunishmentDetail personnelMonthlyAssessmentIndicatorRewardPunishmentDetail);

    /**
     * 修改月度考核指标奖罚明细
     *
     * @param personnelMonthlyAssessmentIndicatorRewardPunishmentDetail 月度考核指标奖罚明细
     * @return 结果
     */
    public int updatePersonnelMonthlyAssessmentIndicatorRewardPunishmentDetail(PersonnelMonthlyAssessmentIndicatorRewardPunishmentDetail personnelMonthlyAssessmentIndicatorRewardPunishmentDetail);

    /**
     * 批量删除月度考核指标奖罚明细
     *
     * @param ids 需要删除的月度考核指标奖罚明细主键集合
     * @return 结果
     */
    public int deletePersonnelMonthlyAssessmentIndicatorRewardPunishmentDetailByIds(Long[] ids);

    /**
     * 删除月度考核指标奖罚明细信息
     *
     * @param id 月度考核指标奖罚明细主键
     * @return 结果
     */
    public int deletePersonnelMonthlyAssessmentIndicatorRewardPunishmentDetailById(Long id);
}
